<?php

namespace ACL\Controllers;

use ACL\Traits\TResponse;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use ACL\Helpers\Instances\InstanceProvider;
use ACL\Util\AclUtilities;
use ACL\Services\Operador as OperadorService;

class Operador {

    use TResponse;

    /**
     * @var OperadorService
     */
    private $operadorService;

    public function __construct(OperadorService $operadorService)
    {
        $this->operadorService = $operadorService;
    }

    public function findAllOperador(Request $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        try {
            $businessPartnership = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRPARCNEGOCIO', true);
            $operatorService = InstanceProvider::getService()->getOperator();
            $operators = $operatorService->findOperator($conditions, $page, $pageSize, $businessPartnership);
            $response->addDataSet(new DataSet('operator', $operators));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findOperadoresByPerfilAcesso(Request $request, Response $response)
    {
        try{
            $nrperfilacesso = $request->getParameter('NRPERFILACESSO');
            $data = $this->operadorService->findOperadoresByPerfilAcesso($nrperfilacesso);
            $this->sendResponse($data, 200);
        }catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findOperadoresForAddPerfilAcesso(Request $request, Response $response)
    {
        try{
            $nrperfilacesso = $request->getParameter('NRPERFILACESSO');
            $data = $this->operadorService->findOperadoresForAddPerfilAcesso($nrperfilacesso);
            $this->sendResponse($data, 200);
        }catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
