<?php

namespace ACL\Repositories;


use ACL\Traits\TQuery;
use ACL\Helpers\Instances\InstanceProvider;
use Doctrine\ORM\EntityManager;

class Operador extends RepositoryBase {

    Use TQuery;

    protected $table = 'OPERADOR';

    /** @var EntityManager */
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        parent::__construct($this->table);
        $this->entityManager = $entityManager;
    }

    /**
     * @param $nrperfilacesso
     * @param $organizationId
     * @return array
     */
    public function findOperadoresByPerfilAcesso($nrperfilacesso, $organizationId): array
    {
        $query = "SELECT CDOPERADOR, NMOPERADOR, NRPERFACESSPARC, NRORG, NRPARCNEGOCIO,
                         NRPERFILACESSO, IDATIVO, TO_CHAR(DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE, IDOPERATIVO
                    FROM (SELECT O.CDOPERADOR, O.NMOPERADOR, P.NRPERFACESSPARC, P.NRORG, P.NRPARCNEGOCIO,
                                 P.NRPERFILACESSO, P.IDATIVO, P.DTVALIDADE, O.IDOPERATIVO
                            FROM PERFACESSPARC P
                            JOIN OPERADOR O ON (P.NRPARCNEGOCIO = O.NRPARCNEGOCIO AND P.NRORG = O.NRORG)
                         )
                   WHERE NRPERFILACESSO = :NRPERFILACESSO
                     AND NRORG = :NRORG
                     AND IDATIVO = 'S'
                     AND IDOPERATIVO = 'A'";

        $params = array(
            'NRORG' => $organizationId,
            'NRPERFILACESSO' => $nrperfilacesso,
        );

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function findOperadoresForAddPerfilAcesso($nrperfilacesso, $organizationId): array
    {
        $query = "SELECT O.CDOPERADOR, O.NMOPERADOR, P.NRPARCNEGOCIO
                    FROM OPERADOR O
               LEFT JOIN PARCNEGOCIO P ON P.NRPARCNEGOCIO = O.NRPARCNEGOCIO
                   WHERE (P.NRPARCNEGOCIO NOT IN (SELECT NRPARCNEGOCIO 
                                                   FROM PERFACESSPARC
                                                  WHERE NRPERFILACESSO = :NRPERFILACESSO
                                                    AND NRORG = :NRORG) OR O.NRPARCNEGOCIO IS NULL)
                     AND O.NRORG = :NRORG
                     AND O.IDATIVO = 'S'
                     AND O.IDOPERATIVO = 'A'
                ";

        $params = array(
            'NRORG' => $organizationId,
            'NRPERFILACESSO' => $nrperfilacesso,
        );

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function createPerfilacesso($newNrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo)
    {
        $arrayData = array(
            'NRPERFILACESSO' => intval($newNrperfilacesso),
            'NMPERFILACESSO' => $nmperfilacesso,
            'IDPERFILACESSOADM' => $idperfilacessoadm,
            'IDATIVO' => $idativo
        );

        $arrayData = $this->auditValuesFieldArrayMerge($arrayData, $this->getAuditFieldValuesDefaultInsert());

        $sql = $this->buildInsert($arrayData);

        $this->insert($sql, $arrayData);
    }

    public function updatePerfilacesso($nrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo)
    {
        $arrayData = array(
            'NMPERFILACESSO' => $nmperfilacesso,
            'IDPERFILACESSOADM' => $idperfilacessoadm,
            'IDATIVO' => $idativo
        );

        $arrayData = $this->auditValuesFieldArrayMerge($arrayData, $this->getAuditFieldValuesDefaultUpdate());

        $arrayConditions = array(
            'NRPERFILACESSO' => intval($nrperfilacesso),
            'NRORG' => intval(InstanceProvider::getLibEnvironment()->getCurrentOrganizationId()),
        );

        $sql = $this->buildUpdate($arrayData, $arrayConditions);
        $arrayData['NRPERFILACESSO'] = intval($nrperfilacesso);
        $arrayData['NRORG'] = intval(InstanceProvider::getLibEnvironment()->getCurrentOrganizationId());

        $this->update($sql, $arrayData);
    }

    public function deletePerfilacesso($nrperfilacesso)
    {
        $arrayConditions = array(
            'NRPERFILACESSO' => intval($nrperfilacesso),
            'NRORG' => intval(InstanceProvider::getLibEnvironment()->getCurrentOrganizationId()),
        );

        $sql = $this->buildDelete($arrayConditions);
        $this->delete($sql, $arrayConditions);
    }
}
