<?php

namespace ACL\Repositories;


use ACL\Traits\TQuery;
use ACL\Helpers\Instances\InstanceProvider;
use Doctrine\ORM\EntityManager;
use Exception;

class Perfilacesso extends RepositoryBase {

    Use TQuery;

    protected $table = 'PERFILACESSO';

    /** @var EntityManager */
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        parent::__construct($this->table);
        $this->entityManager = $entityManager;
    }

    /**
     * @param $organizationId
     * @return array
     */
    public function findAllPerfilacesso($organizationId): array
    {
        $query = "SELECT NRPERFILACESSO, NMPERFILACESSO, IDPERFILACESSOADM, NRORG, IDATIVO
                    FROM PERFILACESSO
                   WHERE NRORG = :NRORG";

        $params = array('NRORG' => $organizationId);

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function createPerfilacesso($newNrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo)
    {
        $arrayData = array(
            'NRPERFILACESSO' => intval($newNrperfilacesso),
            'NMPERFILACESSO' => $nmperfilacesso,
            'IDPERFILACESSOADM' => $idperfilacessoadm,
            'IDATIVO' => $idativo
        );

        $arrayData = $this->auditValuesFieldArrayMerge($arrayData, $this->getAuditFieldValuesDefaultInsert());

        $sql = $this->buildInsert($arrayData);

        $this->insert($sql, $arrayData);
    }

    public function updatePerfilacesso($nrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo)
    {
        $arrayData = array(
            'NMPERFILACESSO' => $nmperfilacesso,
            'IDPERFILACESSOADM' => $idperfilacessoadm,
            'IDATIVO' => $idativo
        );

        $arrayData = $this->auditValuesFieldArrayMerge($arrayData, $this->getAuditFieldValuesDefaultUpdate());

        $arrayConditions = array(
            'NRPERFILACESSO' => intval($nrperfilacesso),
            'NRORG' => intval(InstanceProvider::getLibEnvironment()->getCurrentOrganizationId()),
        );

        $sql = $this->buildUpdate($arrayData, $arrayConditions);
        $arrayData['NRPERFILACESSO'] = intval($nrperfilacesso);
        $arrayData['NRORG'] = intval(InstanceProvider::getLibEnvironment()->getCurrentOrganizationId());

        $this->update($sql, $arrayData);
    }

    public function deletePerfilacesso($nrperfilacesso)
    {
        $arrayConditions = array(
            'NRPERFILACESSO' => intval($nrperfilacesso),
            'NRORG' => intval(InstanceProvider::getLibEnvironment()->getCurrentOrganizationId()),
        );

        $sql = $this->buildDelete($arrayConditions);
        $this->delete($sql, $arrayConditions);
    }

    /**
     * @param $nrorg
     * @return array[]
     * @throws Exception
     */
    public function findAccessControlUtilization($nrorg)
    {
        try {
            $query = "SELECT IDUTCTRLACESWEB
                        FROM PARAMGERAL
                       WHERE NRORG = $nrorg
                       AND IDUTCTRLACESWEB = 'S'";
            return $this->entityManager->getConnection()->fetchAssociative($query);
        } catch (Exception $e) {
            throw new Exception($e->getMessage());
        };
    }
}
