<?php


namespace ACL\Repositories;


use ACL\Helpers\Instances\InstanceProvider;
use Doctrine\DBAL\Driver\Exception;

class RepositoryBase
{
    /**
     * @var \Doctrine\ORM\EntityManager
     */

    private $entityManager;
    /**
     * @var \Teknisa\Libs\Util\Environment
     */

    private $libEnvironment;
    /**
     * @var
     */
    protected $table;

    /**
     * RepositoryBase constructor.
     * @param $table
     * @throws \Exception
     */
    public function __construct($table)
    {
        $this->entityManager = InstanceProvider::getEntityManager();
        $this->libEnvironment = InstanceProvider::getLibEnvironment();
        $this->table = $table;
    }

    /**
     * @param $arrayData
     * @return string
     */
    public function buildInsert(&$arrayData): string
    {
        $sql = "";
        $fields = "";
        $values = "";

        foreach($arrayData as $key => $value) {
            $fields .= $key . ', ';
            if ($value === 'SYSDATE') {
                $values .= "SYSDATE, ";
                unset($arrayData[$key]);
            } else {
                $values .= ":$key, ";
            }
        }

        // Retira vírgula do final da string
        $fields = (substr($fields, -2) == ', ') ? trim(substr($fields, 0, (strlen($fields) - 2))) : $fields ;

        // Retira vírgula do final da string
        $values = (substr($values, -2) == ', ') ? trim(substr($values, 0, (strlen($values) - 2))) : $values ;

        $sql .= "INSERT INTO {$this->table} (" . $fields . ") VALUES (" . $values . ")";

        return trim($sql);
    }

    /**
     * @param $arrayData
     * @param $arrayConditions
     * @return string
     */
    public function buildUpdate(&$arrayData, $arrayConditions): string
    {
        $sql = "";
        $fieldValues = "";
        $conditions = "";

        foreach($arrayData as $key => $value) {
            if ($value === 'SYSDATE') {
                $fieldValues .= $key . " = SYSDATE, ";
                unset($arrayData[$key]);
            } else {
                $fieldValues .= $key . " = :{$key}, ";
            }
        };

        foreach($arrayConditions as $key => $valor):
            $conditions .= $key . " = :{$key} AND ";
        endforeach;

        // Retira vírgula do final da string
        $fieldValues = (substr($fieldValues, -2) == ', ') ? trim(substr($fieldValues, 0, (strlen($fieldValues) - 2))) : $fieldValues ;

        // Retira vírgula do final da string
        $conditions = (substr($conditions, -4) == 'AND ') ? trim(substr($conditions, 0, (strlen($conditions) - 4))) : $conditions ;

        // Concatena todas as variáveis e finaliza a instrução
        $sql .= "UPDATE {$this->table} SET " . $fieldValues . " WHERE " . $conditions;

        return trim($sql);
    }

    /**
     * @param $arrayCondition
     * @return string
     */
    public function buildDelete($arrayCondition): string
    {
        $sql = "";
        $fieldValues= "";

        foreach($arrayCondition as $key => $value):
            $fieldValues .= $key . " = :{$key} AND ";
        endforeach;

        // Retira a palavra AND do final da string
        $fieldValues = (substr($fieldValues, -4) == 'AND ') ? trim(substr($fieldValues, 0, (strlen($fieldValues) - 4))) : $fieldValues ;

        // Concatena todas as variáveis e finaliza a instrução
        $sql .= "DELETE FROM {$this->table} WHERE " . $fieldValues;

        return trim($sql);
    }

    public function insert(string $sql, array $arrayData)
    {
        try {
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->executeQuery($arrayData);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * @param string $sql
     * @param array $arrayData
     * @throws Exception
     * @throws \Doctrine\DBAL\Exception
     */
    public function update(string $sql, array $arrayData){
        try {
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->executeQuery($arrayData);
        } catch (Exception $e) {
            throw $e;
        }
    }

    /**
     * @param string $sql
     * @param array $arrayData
     * @throws Exception
     * @throws \Doctrine\DBAL\Exception
     */
    public function delete(string $sql, array $arrayData){
        try {
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->executeQuery($arrayData);
        } catch (Exception $e) {
            throw $e;
        }
    }

    /**
     * @return array
     */
    public function getAuditFieldValuesDefaultInsert(): array
    {
        return array(
            'NRORG' => intval($this->libEnvironment->getCurrentOrganizationId()),
            'NRORGINCLUSAO' => intval($this->libEnvironment->getCurrentOrganizationId()),
            'CDOPERINCLUSAO' => $this->libEnvironment->getCdOperador(),
            'DTINCLUSAO' => 'SYSDATE',
        );
    }

    public function getAuditFieldValuesDefaultUpdate(): array
    {
        return array(
            'NRORGULTATU' => intval($this->libEnvironment->getCurrentOrganizationId()),
            'CDOPERULTATU' => $this->libEnvironment->getCdOperador(),
            'DTULTATU' => 'SYSDATE',
        );
    }

    /**
     * @param array $arrayData
     * @param array $auditFieldValuesDefault
     * @return array
     */
    public function auditValuesFieldArrayMerge(array $arrayData, array $auditFieldValuesDefault): array
    {
        return array_merge($arrayData, $auditFieldValuesDefault);
    }
}
