<?php

namespace ACL\Services;

use ACL\Helpers\Instances\InstanceProvider;
use ACL\Repositories\Perfilacesso as PerfilDeAcessoRepository;
use Exception;

class Perfilacesso {

    /**
     * @var \Teknisa\Libs\Util\Environment
     */
    private $libEnvironment;

    /**
     * @var PerfilDeAcessoRepository
     */
    private $perfilacessoRepository;

    public function __construct(PerfilDeAcessoRepository $perfilacessoRepository)
    {
        $this->perfilacessoRepository = $perfilacessoRepository;
        $this->libEnvironment =  InstanceProvider::getLibEnvironment();
    }

    /**
     * @return array
     */
    public function findAllPerfilacesso(): array
    {
        $organizationId = InstanceProvider::getLibEnvironment()->getCurrentOrganizationId();
        return $this->perfilacessoRepository->findAllPerfilacesso($organizationId);
    }

    /**
     * @param $nmperfilacesso
     * @param $idperfilacessoadm
     * @param $idativo
     * @return array
     */
    public function createPerfilacesso($nmperfilacesso, $idperfilacessoadm, $idativo): array
    {
        $newCode = InstanceProvider::getNewCode();
        $organizationId = $this->libEnvironment->getCurrentOrganizationId();
        $newNrperfilacesso = $newCode->getCodeByTableName('PERFILACESSO', $organizationId);
        $this->perfilacessoRepository->createPerfilacesso($newNrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo);
        return ['NRPERFILACESSO' => $newNrperfilacesso];
    }

    /**
     * @param $perfisDeAcesso
     */
    public function updatePerfilacesso($perfisDeAcesso)
    {
        foreach ($perfisDeAcesso as $perfil) {
            $this->perfilacessoRepository->updatePerfilacesso($perfil['NRPERFILACESSO'], $perfil['NMPERFILACESSO'],
                                                                $perfil['IDPERFILACESSOADM'], $perfil['IDATIVO']);
        }
    }

    public function deletePerfilacesso($perfisDeAcesso)
    {
        foreach ($perfisDeAcesso as $perfil) {
            $this->perfilacessoRepository->deletePerfilacesso($perfil['NRPERFILACESSO']);
        }
    }

    /**
     * @return array[]
     * @throws Exception
     */
    public function findAccessControlUtilization()
    {
        $organizationId = $this->libEnvironment->getCurrentOrganizationId();
        return $this->perfilacessoRepository->findAccessControlUtilization($organizationId);
    }
}
