import { Http, Metadata, Singleton } from '@zeedhi/core';
import { Form, IGridEvent, LoadingService, Modal, ModalService } from '@zeedhi/common';
import { AclDialogService } from '@/services/AclDialogService';
import { TekGrid, TekRestDatasource } from '@zeedhi/teknisa-components-common';
import { AclAlertService } from '@/services/AclAlertService';
import Messages from '@/services/Messages';

@Singleton
export class PerfilDeAcessoController {
	/**
	 * Perfil de Acesso Card Section
	 */

	private addPerfilDeAcessoModal!: Modal;

	public containerLabel!: string;

	public actionEnableAccessProfileLabel!: string;

	public async onCreatedPerfilDeAcessoCard() {
		try {
			Http.post('/novocodigo/validate');
			this.findAccessControlUtilization();
			this.addPerfilDeAcessoModal = await ModalService.createFromJson('modais/perfil-de-acesso/addPerfilDeAcesso', true);
		} catch (e) {
			LoadingService.hide();
			AclDialogService.showErrorBackend(e);
		}
	}

	private async findAccessControlUtilization() {
		const response = await Http.get('/findAccessControlUtilization');
		let idutctrlacesweb: string;

		if (response.data.IDUTCTRLACESWEB) {
			idutctrlacesweb = response.data.IDUTCTRLACESWEB;
		} else {
			idutctrlacesweb = 'N';
		}

		localStorage.setItem('idutctrlacesweb', idutctrlacesweb);
		this.changeLabelEnableAccessProfile(idutctrlacesweb);
	}

	private changeLabelEnableAccessProfile(idutctrlacesweb: string) {
		if (idutctrlacesweb === 'N') {
			this.containerLabel = 'Access Profile (Access Control Disabled)';
			this.actionEnableAccessProfileLabel = 'Enable Access Control';
		} else {
			this.containerLabel = 'Access Profile';
			this.actionEnableAccessProfileLabel = 'Disable Access Control';
		}
	}

	public destroyPerfilDeAcessoCard() {
		this.addPerfilDeAcessoModal?.destroy();
	}

	/**
	 * Perfil de Acesso Grid Section
	 */
	public isVisiblePerfilDeAcessoGrid = true;

	public currentPerfilDeAcesso: any = {};

	public getInstancePerfilAcessoGrid(): TekGrid {
		return Metadata.getInstance<TekGrid>('perfilDeAcessoGrid');
	}

	public getColumnStyle(params: any) {
		return params.row.IDATIVO === 'N' ? 'acl-grid-column-inactive' : '';
	}

	public async onMountedPerfilDeAcessoGrid() {
		const grid = this.getInstancePerfilAcessoGrid();
		if (grid.datasource instanceof TekRestDatasource) {
			grid.datasource.dynamicFilter = {
				IDATIVO: [
					{
						operation: 'EQUALS',
						relation: 'AND',
						value: 'S',
					},
				],
			};

			try {
				await grid.datasource.get();
			} catch (e) {
				AclDialogService.showErrorBackend(e);
			}
		}
	}

	public addClickPerfilDeAcessoGrid() {
		this.addPerfilDeAcessoModal.show();
	}

	public closeAddPerfilDeAcessoModal() {
		this.addPerfilDeAcessoModal.hide();
	}

	public async saveAddPerfilDeAcessoModal() {
		const addForm = Metadata.getInstance<Form>('addPerfilDeAcessoModalForm');
		const grid = this.getInstancePerfilAcessoGrid();

		if (addForm.validate()) {
			try {
				LoadingService.show();
				await Http.post('/perfilacesso', addForm.value);
				LoadingService.hide();
				this.addPerfilDeAcessoModal.hide();
				await grid.reload();
			} catch (e) {
				LoadingService.hide();
				AclDialogService.showErrorBackend(e);
			}
		}
	}

	public async beforeSavePerfilDeAcessoGrid({ event }: IGridEvent) {
		event?.preventDefault();
		const grid = this.getInstancePerfilAcessoGrid();
		const modifiedItems = grid.getEditedRows();

		try {
			LoadingService.show();
			await Http.put('/perfilacesso', modifiedItems);
			LoadingService.hide();
			AclAlertService.showSuccess(Messages.SUCCESS_SAVE_DEAFULT);
			await grid.reload();
			await grid.cancelEditedRows();
		} catch (e) {
			LoadingService.hide();
			AclDialogService.showErrorBackend(e);
		}
	}

	public async beforeDeletePerfilDeAcessoGrid({ event }: IGridEvent) {
		event?.preventDefault();
		const confirm = await AclDialogService.confirmDialog(Messages.DELETE_DEFAULT);
		if (confirm) {
			this.deletePerfiDeAcesso();
		}
	}

	private async deletePerfiDeAcesso() {
		try {
			const grid = this.getInstancePerfilAcessoGrid();
			LoadingService.show();
			await Http.delete('/perfilacesso', { data: { rows: grid.selectedRows } });
			LoadingService.hide();
			AclAlertService.showSuccess(Messages.SUCCESS_DELETE_DEAFULT);
			await grid.reload();
		} catch (e) {
			LoadingService.hide();
			AclDialogService.showErrorBackend(e);
		}
	}

	public async cellClickPerfilDeAcessoGrid({ row }: IGridEvent) {
		const operatorGrid = Metadata.getInstance<TekGrid>('perfilDeAcessoOperadorGrid');
		this.isVisiblePerfilDeAcessoGrid = false;
		this.currentPerfilDeAcesso = row;
		await operatorGrid.datasource.addFilter('NRPERFILACESSO', row.NRPERFILACESSO);
	}
}
