import { DialogService } from '@zeedhi/common';
import { Utilities } from '@/services/Utilities';
import Messages from './Messages';

export class AclDialogService extends DialogService {
	public static showSuccess(text: string) {
		this.show({
			name: 'success_dialog',
			type: 'success',
			title: 'Sucesso',
			text,
		});
	}

	public static showError(text: string) {
		this.show({
			name: 'error_dialog',
			type: 'error',
			title: 'Erro',
			text,
		});
	}

	public static showErrorBackend(error: any) {
		let msg = '';
		if (error.response && error.response.data && error.response.data.error) {
			msg = `<b>${error.response.data.error}</b>`;
		} else {
			msg = Messages.ERROR_DEFAULT;
		}
		this.show({
			name: 'error_dialog',
			type: 'error',
			title: 'Erro',
			text: msg,
		});
	}

	public static async confirmDialog(msg: string, type: string = 'warning') {
		return new Promise((resolve) => {
			this.show({
				name: Utilities.getNameDynamic('confirmDialog'),
				type,
				title: 'Confirme',
				text: msg,
				buttons: [
					{
						name: Utilities.getNameDynamic('no'),
						component: 'ZdButton',
						label: 'Não',
						outline: true,
						events: {
							click: () => {
								this.hide();
								resolve(false);
							},
						},
					},
					{
						name: Utilities.getNameDynamic('yes'),
						component: 'ZdButton',
						label: 'Sim',
						events: {
							click: () => {
								this.hide();
								resolve(true);
							},
						},
					},
				],
			});
		});
	}
}
